#region Using declarations
using System;
using System.ComponentModel;
using System.Diagnostics;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.Xml.Serialization;
using NinjaTrader.Cbi;
using NinjaTrader.Data;
using NinjaTrader.Gui.Chart;
#endregion

// This namespace holds all indicators and is required. Do not change it.
namespace NinjaTrader.Indicator
{
    /// <summary>
    /// Enter the description of your new custom indicator here
    /// </summary>
    [Description("Enter the description of your new custom indicator here")]
    public class Coral : Indicator
    {
        #region Variables
        // Wizard generated variables
            private int period = 55; // Default setting for Period
			private DataSeries line;
		
        // User defined variables (add any user defined variables below)
        #endregion

        /// <summary>
        /// This method is used to configure the indicator and is called once before any bar data is loaded.
        /// </summary>
        protected override void Initialize()
        {
            Add(new Plot(Color.FromKnownColor(KnownColor.Orange), PlotStyle.Line, "Plot"));
            Overlay				= true;
        }

        /// <summary>
        /// Called on each bar update event (incoming tick)
        /// </summary>
        protected override void OnBarUpdate()
        {
            // Use this method for calculating your indicator values. Assign a value to each
            // plot below by replacing 'Close[0]' with your own formula.
			
			if (CurrentBar < period) return;
			
			Plot.Set(T3(period,2,.7)[0]);
			
			if (Rising(Plot))
			{
            PlotColors[0][0] = Color.Green;
			}
			else if (Falling(Plot))
			{
				PlotColors[0][0] = Color.Red;
			}
			else
			{
				PlotColors[0][0]= Color.Yellow;
			}
        }

        #region Properties
        [Browsable(false)]	// this line prevents the data series from being displayed in the indicator properties dialog, do not remove
        [XmlIgnore()]		// this line ensures that the indicator can be saved/recovered as part of a chart template, do not remove
        public DataSeries Plot
        {
            get { return Values[0]; }
        }

        [Description("")]
        [GridCategory("Parameters")]
        public int Period
        {
            get { return period; }
            set { period = Math.Max(1, value); }
        }
        #endregion
    }
}

#region NinjaScript generated code. Neither change nor remove.
// This namespace holds all indicators and is required. Do not change it.
namespace NinjaTrader.Indicator
{
    public partial class Indicator : IndicatorBase
    {
        private Coral[] cacheCoral = null;

        private static Coral checkCoral = new Coral();

        /// <summary>
        /// Enter the description of your new custom indicator here
        /// </summary>
        /// <returns></returns>
        public Coral Coral(int period)
        {
            return Coral(Input, period);
        }

        /// <summary>
        /// Enter the description of your new custom indicator here
        /// </summary>
        /// <returns></returns>
        public Coral Coral(Data.IDataSeries input, int period)
        {
            if (cacheCoral != null)
                for (int idx = 0; idx < cacheCoral.Length; idx++)
                    if (cacheCoral[idx].Period == period && cacheCoral[idx].EqualsInput(input))
                        return cacheCoral[idx];

            lock (checkCoral)
            {
                checkCoral.Period = period;
                period = checkCoral.Period;

                if (cacheCoral != null)
                    for (int idx = 0; idx < cacheCoral.Length; idx++)
                        if (cacheCoral[idx].Period == period && cacheCoral[idx].EqualsInput(input))
                            return cacheCoral[idx];

                Coral indicator = new Coral();
                indicator.BarsRequired = BarsRequired;
                indicator.CalculateOnBarClose = CalculateOnBarClose;
#if NT7
                indicator.ForceMaximumBarsLookBack256 = ForceMaximumBarsLookBack256;
                indicator.MaximumBarsLookBack = MaximumBarsLookBack;
#endif
                indicator.Input = input;
                indicator.Period = period;
                Indicators.Add(indicator);
                indicator.SetUp();

                Coral[] tmp = new Coral[cacheCoral == null ? 1 : cacheCoral.Length + 1];
                if (cacheCoral != null)
                    cacheCoral.CopyTo(tmp, 0);
                tmp[tmp.Length - 1] = indicator;
                cacheCoral = tmp;
                return indicator;
            }
        }
    }
}

// This namespace holds all market analyzer column definitions and is required. Do not change it.
namespace NinjaTrader.MarketAnalyzer
{
    public partial class Column : ColumnBase
    {
        /// <summary>
        /// Enter the description of your new custom indicator here
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.Coral Coral(int period)
        {
            return _indicator.Coral(Input, period);
        }

        /// <summary>
        /// Enter the description of your new custom indicator here
        /// </summary>
        /// <returns></returns>
        public Indicator.Coral Coral(Data.IDataSeries input, int period)
        {
            return _indicator.Coral(input, period);
        }
    }
}

// This namespace holds all strategies and is required. Do not change it.
namespace NinjaTrader.Strategy
{
    public partial class Strategy : StrategyBase
    {
        /// <summary>
        /// Enter the description of your new custom indicator here
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.Coral Coral(int period)
        {
            return _indicator.Coral(Input, period);
        }

        /// <summary>
        /// Enter the description of your new custom indicator here
        /// </summary>
        /// <returns></returns>
        public Indicator.Coral Coral(Data.IDataSeries input, int period)
        {
            if (InInitialize && input == null)
                throw new ArgumentException("You only can access an indicator with the default input/bar series from within the 'Initialize()' method");

            return _indicator.Coral(input, period);
        }
    }
}
#endregion
